#include "ow-bus.h"


//-----------------------------------------------------------------------------
// Generate a 1-Wire reset, return 1 if no presence detect was found,
// return 0 otherwise.
// (NOTE: Does not handle alarm presence from DS2404/DS1994)
//
int OWTouchReset(void)
{
   int result;
   
   //SFIOR &= ~(1<<PUD);  //PUD in SFIOR auf 0 setzen, wegen Pull-Up
   //SFIOR |= (1<<PUD);   // PUD setzen, Pull-Up aus: in Register SFIOR bei mega8
   MCUCR |= (1<<PUD);   // PUD setzen, Pull-Up aus: in Register MCUCR bei mega644P
   
   _delay_us(G);
   
   // folgende zwei Zeilen setzen DQ auf Low
   OW_PORT &= ~(1<<OW_DATA);	//Portbit lschen
   OW_DDR |= (1<<OW_DIR);	//Richtungsregister auf Ausgang setzen
   
   _delay_us(H);

   // folgende zwei Zeilen legen den Pull-Up an den Bus
   OW_DDR &= ~(1<<OW_DIR);	//Richtungsregister auf Eingang setzen
   OW_PORT |= (1<<OW_DATA);	// Pull-Up aktivieren
      
   _delay_us(I);
   result = OW_PINREG & (1<<OW_PIN); // Sample for presence pulse from slave
   _delay_us(J); // Complete the reset sequence recovery
   
   return result; // Return sample presence pulse result; 0: device(s) present, 1: no device present
}

//-----------------------------------------------------------------------------
// Send a 1-Wire write bit. Provide 10us recovery time.
//
void OWWriteBit(int bit)
{//outp
   if (bit)
   {  
      // Write '1' bit

      // folgende zwei Zeilen setzen DQ auf Low
      OW_PORT &= ~(1<<OW_DATA);	//Portbit lschen
      OW_DDR |= (1<<OW_DIR);	    //Richtungsregister auf Ausgang setzen
      
      _delay_us(A);

      // folgende zwei Zeilen legen den Pull-Up an den Bus
      OW_DDR &= ~(1<<OW_DIR);	//Richtungsregister auf Eingang setzen
      OW_PORT |= (1<<OW_DATA);	    // Pull-Up aktivieren

      _delay_us(B); // Complete the time slot and 10us recovery
   }
   else
   {
      // Write '0' bit

      // folgende zwei Zeilen setzen DQ auf Low
      OW_PORT &= ~(1<<OW_DATA);	//Portbit lschen
      OW_DDR |= (1<<OW_DIR);	    //Richtungsregister auf Ausgang setzen

      _delay_us(C);
      
      // folgende zwei Zeilen legen den Pull-Up an den Bus
      OW_DDR &= ~(1<<OW_DIR);	//Richtungsregister auf Eingang setzen
      OW_PORT |= (1<<OW_DATA);	    // Pull-Up aktivieren

      _delay_us(D);
   }
}
//-----------------------------------------------------------------------------
// Read a bit from the 1-Wire bus and return it. Provide 10us recovery time.
//
int OWReadBit(void)
{
   int result;
   
   // folgende zwei Zeilen setzen DQ auf Low
   OW_PORT &= ~(1<<OW_DATA);	//Portbit lschen
   OW_DDR |= (1<<OW_DIR);	//Richtungsregister auf Ausgang setzen

   _delay_us(A);

   // folgende zwei Zeilen legen den Pull-Up an den Bus
   OW_DDR &= ~(1<<OW_DIR);	//Richtungsregister auf Eingang setzen
   OW_PORT |= (1<<OW_DATA);	// Pull-Up aktivieren

   _delay_us(E);
   result = OW_PINREG & (1<<OW_PIN); // Sample the bit value from the slave
   _delay_us(F); // Complete the time slot and 10us recovery
   
   return result;
}

//-----------------------------------------------------------------------------
// Write 1-Wire data byte
//
void OWWriteByte(int data)
{
   int loop;

   // Loop to write each bit in the byte, LS-bit first
   for (loop = 0; loop < 8; loop++) 
   {
      OWWriteBit(data & 0x01);
      // shift the data byte for the next bit
      data >>= 1;
   }
}

//-----------------------------------------------------------------------------
// Read 1-Wire data byte and return it
//
int OWReadByte(void)
{
   int loop, result=0;

   for (loop = 0; loop < 8; loop++)
   {
      // shift the result to get it ready for the next bit
      result >>= 1;
      // if result is one, then set MS bit
      if (OWReadBit()) result |= 0x80;
	      
   }

   return result;
}

//-----------------------------------------------------------------------------
// Write a 1-Wire data byte and return the sampled result.
//
int OWTouchByte(int data)
{
   int loop, result=0;

   for (loop = 0; loop < 8; loop++)
   {
      // shift the result to get it ready for the next bit
      result >>= 1;
      // If sending a '1' then read a bit else write a '0'
      if (data & 0x01)
      {
         if (OWReadBit())
           result |= 0x80;
      }
      else
        OWWriteBit(0);
      // shift the data byte for the next bit
      data >>= 1;
   }

   return result;
}
