// OW-bus.h

// Routinen fr den Dallas/Maxim 1-Wire Bus

#include <avr/io.h>
#include <util/delay.h>



 
// Pausen fr Verzgerung definieren: in s, Standard-Geschwindigkeit, kein Overdrive
#define A 6
#define B 64
#define C 60
#define D 10
#define E 9
#define F 55
#define G 0
#define H 480
#define I 70
#define J 410

// Pinbelegung fr den 1-Wire Bus, an verwendete Pins anpassen
#define OW_PORT       PORTA
#define OW_DDR        DDRA
#define OW_PINREG	  PINA
#define OW_DATA       PB4
#define OW_DIR		  DDB4
#define OW_PIN	      PINB4






//-----------------------------------------------------------------------------
// Generate a 1-Wire reset, return 1 if no presence detect was found,
// return 0 otherwise.
// (NOTE: Does not handle alarm presence from DS2404/DS1994)
//
extern int OWTouchReset(void);



//-----------------------------------------------------------------------------
// Send a 1-Wire write bit. Provide 10us recovery time.
//
extern void OWWriteBit(int bit);




//-----------------------------------------------------------------------------
// Read a bit from the 1-Wire bus and return it. Provide 10us recovery time.
//
extern int OWReadBit(void);




//-----------------------------------------------------------------------------
// Write 1-Wire data byte
//
extern void OWWriteByte(int data);




//-----------------------------------------------------------------------------
// Read 1-Wire data byte and return it
//
extern int OWReadByte(void);




//-----------------------------------------------------------------------------
// Write a 1-Wire data byte and return the sampled result.
//
extern int OWTouchByte(int data);






